@@ -19,7 +19,7 @@ import numpy as np
 from numpy import (
     array, arange, empty, zeros, int32, int64, uint16, complex_, float64, rec,
     copy, ones_like, where, alltrue, linspace,
-    sum, prod, sqrt, fmod,
+    sum, prod, sqrt, fmod, floor, ceil,
     sin, cos, tan, arcsin, arccos, arctan, arctan2,
     sinh, cosh, tanh, arcsinh, arccosh, arctanh,
     log, log1p, log10, exp, expm1, conj)
@@ -100,6 +100,12 @@ class test_numexpr(TestCase):
         assert_allclose(evaluate("min(x)"), np.min(x))
         assert_allclose(evaluate("max(x,axis=0)"), np.max(x, axis=0))
 
+        # Fix for #277, array with leading singleton dimension
+        x = np.arange(10).reshape(1,10)
+        assert_allclose(evaluate("sum(x,axis=None)"), sum(x, axis=None) )
+        assert_allclose(evaluate("sum(x,axis=0)"), sum(x, axis=0) )
+        assert_allclose(evaluate("sum(x,axis=1)"), sum(x, axis=1) )
+
         x = arange(10.0)
         assert_allclose(evaluate("sum(x**2+2,axis=0)"), sum(x ** 2 + 2, axis=0))
         assert_allclose(evaluate("prod(x**2+2,axis=0)"), prod(x ** 2 + 2, axis=0))
@@ -516,7 +522,8 @@ func1tests = []
 for func in ['copy', 'ones_like', 'sqrt',
              'sin', 'cos', 'tan', 'arcsin', 'arccos', 'arctan',
              'sinh', 'cosh', 'tanh', 'arcsinh', 'arccosh', 'arctanh',
-             'log', 'log1p', 'log10', 'exp', 'expm1', 'abs', 'conj']:
+             'log', 'log1p', 'log10', 'exp', 'expm1', 'abs', 'conj',
+             'ceil', 'floor']:
     func1tests.append("a + %s(b+c)" % func)
 tests.append(('1_ARG_FUNCS', func1tests))
 
@@ -653,7 +660,8 @@ def test_expressions():
                     for expr in section_tests:
                         if (dtype == complex and
                             ('<' in expr or '>' in expr or '%' in expr
-                             or "arctan2" in expr or "fmod" in expr)):
+                             or "arctan2" in expr or "fmod" in expr
+                             or "floor" in expr or "ceil" in expr)):
                             # skip complex comparisons or functions not
                             # defined in complex domain.
                             continue
@@ -1007,7 +1015,7 @@ def print_versions():
     print('-=' * 38)
 
 
-def test():
+def test(verbosity=1):
     """
     Run all the tests in the test suite.
     """
@@ -1017,7 +1025,7 @@ def test():
     # Ignoring them in tests should be ok, as all results are checked out.
     # See https://github.com/pydata/numexpr/issues/183 for details.
     np.seterr(divide='ignore', invalid='ignore', over='ignore', under='ignore')
-    return unittest.TextTestRunner().run(suite())
+    return unittest.TextTestRunner(verbosity=verbosity).run(suite())
 
 
 test.__test__ = False
